fedex.services.track_service.FedexTrackRequest

Package fedex :: Package services :: Module track_service :: Class FedexTrackRequest |
[hide private]
[frames] | no frames]

# Class FedexTrackRequest

source code

This class allows you to track shipments by providing a tracking number or other identifying features. By default, you can simply pass a tracking number to the constructor. If you would like to query shipments based on something other than tracking number, you will want to read the documentation for the __init__ method. Particularly, the tracking_value and package_identifier arguments.

Instance Methods | [hide private]
__init__(self, config_obj, *args, **kwargs) Sends a shipment tracking request. | source code
_prepare_wsdl_objects(self) This sets the package identifier information. | source code
_check_response_for_request_errors(self) Checks the response to see if there were any errors specific to this WSDL. | source code
_assemble_and_send_request(self) Fires off the Fedex request. | source code
Inherited from `base_service.FedexBaseService`: `create_wsdl_object_of_type`, `send_request` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
| TrackPackageIdentifier Holds the TrackPackageIdentifier WSDL object.
Inherited from `base_service.FedexBaseService`: `ClientDetail`, `TransactionDetail`, `VersionId`, `WebAuthenticationDetail`, `config_obj`, `logger`, `response`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, config_obj, *args, **kwargs) (Constructor) | source code
Sends a shipment tracking request. The optional keyword args detailed on FedexBaseService apply here as well. Parameters: `config_obj` (FedexConfig) - A valid FedexConfig object. Overrides: object.__init__

### _prepare_wsdl_objects(self) | source code
This sets the package identifier information. This may be a tracking number or a few different things as per the Fedex spec.

### _check_response_for_request_errors(self) | source code
Checks the response to see if there were any errors specific to this WSDL. Overrides: base_service.FedexBaseService._check_response_for_request_errors

### _assemble_and_send_request(self) | source code
Fires off the Fedex request. Warning: NEVER CALL THIS METHOD DIRECTLY. CALL send_request(), WHICH RESIDES ON FedexBaseService AND IS INHERITED.